// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.


#include "EpicInstrInfo.h"


using namespace std;

EpicInstrInfo::EpicInstrInfo()
{


}


EpicInstrInfo::EpicInstrInfo(string obsID, Xmm::Instrument instr,
		string expoID) : _obsID(obsID) ,
		_instr(instr), _expoID(expoID)
{

}

void EpicInstrInfo::setObsID(string obsID)
{
	_obsID = obsID;
}

string EpicInstrInfo::getObsID()
{
	return _obsID;
}

void EpicInstrInfo::setInstr(Xmm::Instrument instr)
{
	_instr = instr;
}

Xmm::Instrument EpicInstrInfo::getInstr()
{
	return _instr;
}

void EpicInstrInfo::setExposure(double expo)
{
	_exposure = expo;
}

double EpicInstrInfo::getExposure()
{
	return _exposure;
}

void EpicInstrInfo::setExposureID(string expoID)
{
	_expoID = expoID;
}

string EpicInstrInfo::getExposureID()
{
	return _expoID;
}

void EpicInstrInfo::setBackscale(double backscale)
{
	_backscale = backscale;
}

double EpicInstrInfo::getBackscale()
{
	return _backscale;
}

void EpicInstrInfo::setFileName(string fileName)
{
	_fileName = fileName;
}

string EpicInstrInfo::getFileName()
{
	return _fileName;
}


void EpicInstrInfo::setType(string type)
{
	_type = type;
}

string EpicInstrInfo::getType()
{

	return _type;
}


void EpicInstrInfo::setTLMin(int tlmin)
{
	_tlmin = tlmin;
}

int EpicInstrInfo::getTLMin()
{

	return _tlmin;
}


void EpicInstrInfo::setTLMax(int tlmax)
{
	_tlmax = tlmax;
}

int EpicInstrInfo::getTLMax()
{

	return _tlmax;
}


void EpicInstrInfo::setNPI(int npi)
{
	_npi = npi;
}

int EpicInstrInfo::getNPI()
{
	return _npi;
}

void EpicInstrInfo::pushSpectra(EpicInstrInfo *e)
{
	_spectra.push_back(e);

}

vector<EpicInstrInfo*> EpicInstrInfo::getSpectra(string type)
{
	vector<EpicInstrInfo*> e;
	//if (std::find(_spectra.begin(), _spectra.end(), instr) != _spectra.end()
	//		&& std::find(_spectra.begin(), _spectra.end(), type) != _spectra.end() )
	//	e.push_back(_spectra[i]);

	for (unsigned i = 0 ; i < _spectra.size() ; ++i)
	{
		string ins = Xmm::toString(_spectra[i]->getInstr());

		if ( _spectra[i]->getType() == type)
			e.push_back(_spectra[i]);

	}

	return e;
}


double EpicInstrInfo::getExposure(int id, string type)
{

	vector<EpicInstrInfo*> e = getSpectra(type);

	//Open file and get the ObsID and Instrument identifier.

	return e[id]->getExposure();


}


